/*
 *  LibRoadnav
 *  MapControlDataImporter_StateBoundaries.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// This file contains, MapControlDataImporter_StateBoundaries, which imports
/// the boundaries of the US states.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef MAPCONTROLDATAIMPORTER_STATEBOUNDARIES_H
#define MAPCONTROLDATAIMPORTER_STATEBOUNDARIES_H

#include <wx/datetime.h>

#include <map>
#include <vector>
#include <string>

#include "Constants.h"
#include "Point.h"
#include "MapControlDataEntry_Std.h"
#include "MapControlData.h"
#include "MapControlDataImporter.h"

typedef std::vector<std::string> vstring;

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Imports state boundaries
///
//////////////////////////////////////////////////////////////////////////////
class MapControlDataImporter_StateBoundaries : public MapControlDataImporter
{
	public: // public functions
		MapControlDataImporter_StateBoundaries(char * pszSource = NULL);
		virtual ~MapControlDataImporter_StateBoundaries();
	
		static bool IsLoaded();
		bool Download(IMapControlData * pData, ProgressDialog * pdlgProgress = NULL, int iProgressStart = 0, int iProgressTicks = 1);

		virtual IMapControlDataEntry * GetRecord(wxUint32 iIndex);
		virtual int Count();

	private:
		bool Load(wxString strBaseName);
		bool LoadIndex(wxString strBaseName);

		void Clear();

	private: // private member variables

		/// the records themselves
		MapControlDataEntry_Std * m_psRecords;
		
		/// the number of records
		int m_nRecords;

		std::map<wxUint16,vstring> m_mapIndex;
};

#endif
